@@ -11,14 +11,14 @@ from datetime import datetime, timedelta
 
 ALERTS_TABLE = 'alerts.items'
 ALERTS_CONFIGS_TABLE = 'alerts.config'
-METRICS_TIMESERIES_TABLE = 'metrics.details'
+METRICS_DETAILS_TABLE = 'metric.details'
 LOGS_METRICS_FETCHING_TABLE = 'logs.cloud_metric_fetching'
 COMPONENTS_TABLE = 'component.info'
 
+
 ############ ALERTS ###########################
-def insert_alert(alert_id, metric_id, org_id, app_id, team_id, assigned_to, start_time,
-  end_time, alert_description, is_acknowledged, anomalies_dict, related_prev_anomalies,
-  service_graph, significance_score, dynamodb):
+def insert_alert(alert_id, metric_id, org_id, app_id, team_id, assigned_to, start_time, end_time, alert_description,
+                 is_acknowledged, anomalies_dict, related_prev_anomalies, service_graph, significance_score, dynamodb):
   '''
   insert_alert(alert_id = "256828", metric_id = 123, org_id = 'org_id', app_id = 'app_id', team_id = 'team_id', assigned_to = 'Jorge', \
   start_time = '2020-09-03 12:00:00', end_time = '2020-09-03 12:20:00', alert_description = 'Spike in costs',\
@@ -26,58 +26,59 @@ def insert_alert(alert_id, metric_id, org_id, app_id, team_id, assigned_to, star
   service_graph = {}, significance_score = '34.3')
   '''
   alert_dict = {
-    'alert_id' : alert_id,
-    'metric_id' : metric_id,
-    'org_id': org_id,
-    'app_id': app_id,
-    'team_id' : team_id,
-    'assigned_to' : assigned_to,
-    'start_time' : start_time,
-    'end_time' : end_time,
-    'alert_description' : alert_description,
-    'is_acknowledged' : is_acknowledged,
-    'anomalies_dict' : anomalies_dict,
-    'related_prev_anomalies' : related_prev_anomalies,
-    'service_graph': service_graph,
-    'significance_score':  significance_score
+      'alert_id': alert_id,
+      'metric_id': metric_id,
+      'org_id': org_id,
+      'app_id': app_id,
+      'team_id': team_id,
+      'assigned_to': assigned_to,
+      'start_time': start_time,
+      'end_time': end_time,
+      'alert_description': alert_description,
+      'is_acknowledged': is_acknowledged,
+      'anomalies_dict': anomalies_dict,
+      'related_prev_anomalies': related_prev_anomalies,
+      'service_graph': service_graph,
+      'significance_score': significance_score
   }
 
   print(alert_dict)
   response = put_item(alert_dict, ALERTS_TABLE, dynamodb)
   return response
 
+
 def get_alert_item_by_key(anom_id, dynamodb):
   key_dict = {
-    "alert_id" : anom_id,
+      "alert_id": anom_id,
   }
   alert_item = get_item(key_dict, ALERTS_TABLE, dynamodb)
   return alert_item
 
+
 def update_alert_with_related_anomalies(alert_id, start_time, corr_anoms_dict, related_prev_anomalies, dynamodb):
   #https://stackoverflow.com/questions/52367094/how-to-update-dynamodb-table-with-dict-data-type-boto3
   #TODO add similar alerts
   update_expression = "set anomalies_dict=:a, related_prev_anomalies=:r"
   expression_attr_values = {
-    ':a': corr_anoms_dict,
-    ':r': related_prev_anomalies,
+      ':a': corr_anoms_dict,
+      ':r': related_prev_anomalies,
   }
   key_dict = {
-    'alert_id' : alert_id,
-    'start_time' : start_time,
+      'alert_id': alert_id,
+      'start_time': start_time,
   }
 
   update_item(key_dict, update_expression, expression_attr_values, ALERTS_TABLE, dynamodb)
 
   return True
 
+
 def terminate_alert(alert_id, start_time, end_timestamp, dynamodb):
   update_expression = "set end_timestamp=:e"
-  expression_attr_values = {
-    ':e': end_timestamp
-  }
+  expression_attr_values = {':e': end_timestamp}
   key_dict = {
-    'alert_id' : alert_id,
-    'start_time' : start_time,
+      'alert_id': alert_id,
+      'start_time': start_time,
   }
 
   update_item(key_dict, update_expression, expression_attr_values, ALERTS_TABLE, dynamodb)
@@ -88,9 +89,8 @@ def terminate_alert(alert_id, start_time, end_timestamp, dynamodb):
 ############ METRICS ##########################
 #create new metric_timeseries item for current day
 #TODO add unit to create metric
-def create_metric(id, name, provider, namespace, region_name,
-  agent, org_id, component_id, alignment, dimension_name, dimension_value,
-  description, is_active, dynamodb):
+def create_metric(id, name, provider, namespace, region_name, agent, org_id, component_id, alignment, dimension_name,
+                  dimension_value, description, is_active, dynamodb):
   '''
   create_metric(
     id = "test1", name = "error_rate",
@@ -101,31 +101,32 @@ def create_metric(id, name, provider, namespace, region_name,
   )
   '''
   metric_dict = {
-    "id": id,
-    "name": name,
-    "provider": provider,
-    "namespace": namespace,
-    "region_name": region_name,
-    "agent": agent,
-    "org_id": org_id,
-    "component_id": component_id,
-    "alignment": alignment,
-    "dimension_value": dimension_value,
-    "dimension_name": dimension_name,
-    "description": description,
-    "is_active": is_active
+      "id": id,
+      "name": name,
+      "provider": provider,
+      "namespace": namespace,
+      "region_name": region_name,
+      "agent": agent,
+      "org_id": org_id,
+      "component_id": component_id,
+      "alignment": alignment,
+      "dimension_value": dimension_value,
+      "dimension_name": dimension_name,
+      "description": description,
+      "is_active": is_active
   }
 
-
   #print(alert_dict)
-  response = put_item(metric_dict, METRICS_TIMESERIES_TABLE, dynamodb)
+  response = put_item(metric_dict, METRICS_DETAILS_TABLE, dynamodb)
   return response
 
+
 #batch insert metrics
 def chunks(lst, n):
-    """Yield successive n-sized chunks from lst."""
-    for i in range(0, len(lst), n):
-        yield lst[i:i + n]
+  """Yield successive n-sized chunks from lst."""
+  for i in range(0, len(lst), n):
+    yield lst[i:i + n]
+
 
 #deprecated
 def batch_insert_metric_objects(list_of_metric_objects, dynamodb):
@@ -142,7 +143,8 @@ def batch_insert_metric_objects(list_of_metric_objects, dynamodb):
       curr_metric = metric_obj.to_dict()
       curr_metric['date_bucket'] = date
       metric_list.append(curr_metric)
-    batch_insert(metric_list, METRICS_TIMESERIES_TABLE, dynamodb)
+    batch_insert(metric_list, METRICS_DETAILS_TABLE, dynamodb)
+
 
 def batch_insert_metric_details_objects(list_of_metric_objects, dynamodb):
   #convert list of metric objects into list of metric dicts
@@ -153,38 +155,34 @@ def batch_insert_metric_details_objects(list_of_metric_objects, dynamodb):
       curr_metric = metric_obj.to_dict()
       #decide which are going to be the key attrs
       metric_list.append(curr_metric)
-    batch_insert(metric_list, METRICS_TIMESERIES_TABLE, dynamodb)
+    batch_insert(metric_list, METRICS_DETAILS_TABLE, dynamodb)
+
 
 def get_metric_details(metric_id, dynamodb):
-  date = datetime.today() - timedelta(days=1)
-  date = str(date).split(' ')[0]
-  key_dict = {
-    "metric_id" : metric_id,
-    "date_bucket" : date,
-  }
-  attr_list = ['metric_id', 'metric_name', 'namespace','metric_alignment', 'dimensions']
-  metric_details = get_item_and_retrieve_specific_attributes(key_dict, attr_list, METRICS_TIMESERIES_TABLE, dynamodb)
+  key_dict = {"id": metric_id}
+  attr_list = ['id', 'name', 'namespace', 'alignment', 'dimension_name', 'dimension_value', 'org_id', 'is_active']
+  metric_details = get_item_and_retrieve_specific_attributes(key_dict, attr_list, METRICS_DETAILS_TABLE, dynamodb)
   return metric_details
 
+
 #query metrics info by metric_id key
 def get_metric_item_by_key(metric_id, curr_date, dynamodb):
   #get_metric_item_by_key(123, '2020-09-10')
-  key_dict = {
-    "metric_id" : metric_id,
-    "date_bucket" : str(curr_date)
-  }
+  key_dict = {"metric_id": metric_id, "date_bucket": str(curr_date)}
 
   metric_item = get_item(key_dict, 'metric.ts', dynamodb)
   return metric_item
 
+
 def scan_metrics_by_encrypted_id(anom_alarm_id, dynamodb):
   scan_kwargs = {
-    'FilterExpression': Attr('encrypted_id').eq(anom_alarm_id),
+      'FilterExpression': Attr('encrypted_id').eq(anom_alarm_id),
   }
   metric_list = scan_table(scan_kwargs, 'metric.ts', dynamodb)
   metric_item = metric_list[0]
   return metric_item
 
+
 ############## COMPONENTS ###################
 def batch_insert_component_info_objects(list_of_component_objects, dynamodb):
   # convert list of metric objects into list of metric dicts
@@ -197,14 +195,16 @@ def batch_insert_component_info_objects(list_of_component_objects, dynamodb):
       component_list.append(curr_component)
     batch_insert(component_list, COMPONENTS_TABLE, dynamodb)
 
+
 ############## ALERT CONFIGS ################
 def query_alerts_configs_by_key(metric_id, dynamodb):
   key_condition = Key('metric_id').eq(metric_id)
   alerts_configs_list = query_by_key(key_condition, ALERTS_CONFIGS_TABLE, dynamodb)
   return alerts_configs_list
 
-def insert_alert_config(metric_id, alert_title, severity, alert_type, alert_direction, description,
-  duration, duration_unit, rule_dict, recipients_list, owner_dict, dynamodb):
+
+def insert_alert_config(metric_id, alert_title, severity, alert_type, alert_direction, description, duration,
+                        duration_unit, rule_dict, recipients_list, owner_dict, dynamodb):
   '''
   insert_alert_config(
     metric_id = "metric1245", alert_title = "Anomaly by Cluster", severity = "critical",
@@ -224,23 +224,24 @@ def insert_alert_config(metric_id, alert_title, severity, alert_type, alert_dire
   )
   '''
   alert_dict = {
-    "metric_id" : metric_id,
-    "alert_title" : alert_title,
-    "severity" : severity,
-    "alert_type" : alert_type,
-    "alert_direction" : alert_direction,
-    "description" : description,
-    "duration" : duration,
-    "duration_unit" : duration_unit,
-    "rule_dict" : rule_dict,
-    "recipients" : recipients_list,
-    "owner" : owner_dict
+      "metric_id": metric_id,
+      "alert_title": alert_title,
+      "severity": severity,
+      "alert_type": alert_type,
+      "alert_direction": alert_direction,
+      "description": description,
+      "duration": duration,
+      "duration_unit": duration_unit,
+      "rule_dict": rule_dict,
+      "recipients": recipients_list,
+      "owner": owner_dict
   }
 
   #print(alert_dict)
   response = put_item(alert_dict, 'alerts.config')
   return response
 
+
 ############## LOGS #########################
 def query_most_recent_metric_fetching_log(component_id, dynamodb):
   '''
@@ -255,6 +256,7 @@ def query_most_recent_metric_fetching_log(component_id, dynamodb):
   else:
     return None
 
+
 ############## EXAMPLES #####################
 def update_values_in_dict_attr():
   '''
